@@ -5,7 +5,7 @@ use warnings;
 
 use Alien::Base::PkgConfig;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -36,7 +36,7 @@ Alien::Base - Base classes for Alien:: modules
 (For a synopsis of the C<Build.PL> that comes with your
 C<Alien::MyLibrary> see L<Alien::Base::ModuleBuild>)
 
-Then an C<MyLibrary::XS> can use C<Alien::MyLibrary> in their C<Build.PL>:
+Then a C<MyLibrary::XS> can use C<Alien::MyLibrary> in its C<Build.PL>:
 
  use Alien::MyLibrary;
  use Module::Build 0.28; # need at least 0.28
@@ -50,7 +50,7 @@ Then an C<MyLibrary::XS> can use C<Alien::MyLibrary> in their C<Build.PL>:
  
  $builder->create_build_script;
 
-Or if you prefer L<ExtUtils::MakeMaker>, the C<Makefile.PL>:
+Or if you prefer L<ExtUtils::MakeMaker>, in its C<Makefile.PL>:
 
  use Alien::MyLibrary
  use ExtUtils::MakeMaker;
@@ -62,6 +62,16 @@ Or if you prefer L<ExtUtils::MakeMaker>, the C<Makefile.PL>:
    ...
  );
 
+Or if you are using L<ExtUtils::Depends>:
+
+ use ExtUtils::MakeMaker;
+ use ExtUtils::Depends;
+ my $eud = ExtUtils::Depends->new(qw( MyLibrary::XS Alien::MyLibrary ));
+ WriteMakefile(
+   ...
+   $eud->get_makefile_vars
+ );
+
 In your C<MyLibrary::XS> module, you may need to use L<Alien::MyLibrary> if
 dynamic libraries are used:
 
@@ -82,6 +92,15 @@ Or you can use it from an FFI module:
  
  FFI::Raw->new($dll, 'my_library_function', FFI::Raw::void);
 
+You can even use it with L<Inline> (C and C++ languages are supported):
+
+ package MyLibrary::Inline;
+ 
+ use Alien::MyLibrary;
+ # Inline 0.56 or better is required
+ use Inline 0.56 with => 'Alien::MyLibrary';
+ ...
+
 =head1 DESCRIPTION
 
 L<Alien::Base> comprises base classes to help in the construction of C<Alien::> modules. Modules in the L<Alien> namespace are used to locate and install (if necessary) external libraries needed by other Perl modules.
@@ -242,6 +261,7 @@ sub _keyword {
     my $name = $self->config('name');
     my $command = Alien::Base::PkgConfig->pkg_config_command . " --\L$keyword\E $name";
 
+    $! = 0;
     chomp ( my $pcdata = capture_merged { system( $command ) } );
     croak "Could not call pkg-config: $!" if $!;
 
@@ -301,7 +321,7 @@ sub pkgconfig {
 
 Returns the configuration data as determined during the install
 of L<Alien::MyLibrary>.  For the appropriate config keys, see 
-L<Alien::Base::ModuleBuild::API#CONFIG DATA>.
+L<Alien::Base::ModuleBuild::API#CONFIG-DATA>.
 
 =cut
 
@@ -367,6 +387,58 @@ sub dynamic_libs {
   grep { ! -l $_ } map { File::Spec->catfile($dir, $_) } @dlls;
 }
 
+=head2 bin_dir
+
+ my(@dir) = Alien::MyLibrary->bin_dir
+
+Returns a list of directories with executables in them.  For a C<system>
+install this will be an empty list.  For a C<share> install this will be
+a directory under C<dist_dir> named C<bin> if it exists.  You may wish
+to override the default behavior if you have executables or scripts that
+get installed into non-standard locations.
+
+=cut
+
+sub bin_dir {
+  my ($class) = @_;
+  my $dir = File::Spec->catfile($class->dist_dir, 'bin');
+  -d $dir ? ($dir) : ();
+}
+
+=head2 inline_auto_include
+
+ my(@headers) = Alien::MyLibrary->inline_auto_include;
+
+List of header files to automatically include in inline C and C++
+code when using L<Inline::C> or L<Inline::CPP>.  This is provided
+as a public interface primarily so that it can be overidden at run
+time.  This can also be specified in your C<Build.PL> with 
+L<Alien::Base::ModuleBuild> using the C<alien_inline_auto_include>
+property.
+
+=cut
+
+sub inline_auto_include {
+  my ($class) = @_;
+  return [] unless $class->config('inline_auto_include');
+  $class->config('inline_auto_include')
+}
+
+sub Inline {
+  my ($class, $language) = @_;
+  return if $language !~ /^(C|CPP)$/;
+  my $config = {
+    CCFLAGSEX    => $class->cflags,
+    LIBS         => $class->libs,
+  };
+  
+  if (@{ $class->inline_auto_include } > 0) {
+    $config->{AUTO_INCLUDE} = join "\n", map { "#include \"$_\"" } @{ $class->inline_auto_include };
+  }
+  
+  $config;
+}
+
 1;
 
 __END__
