@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -13,11 +13,17 @@ use File::chdir;
 use File::Spec;
 use File::Basename qw/fileparse/;
 use Carp;
+no warnings;
 use Archive::Extract;
+use warnings;
 use Sort::Versions;
 use List::MoreUtils qw/uniq first_index/;
 use ExtUtils::Installed;
 use File::Copy qw/move/;
+use Env qw( @PATH );
+use Shell::Guess;
+use Shell::Config::Generate;
+use File::Path qw/mkpath/;
 
 use Alien::Base::PkgConfig;
 use Alien::Base::ModuleBuild::Cabinet;
@@ -106,6 +112,15 @@ __PACKAGE__->add_property( 'alien_repository_class'   => {} );
 __PACKAGE__->add_property( 'alien_isolate_dynamic' => 0 );
 __PACKAGE__->add_property( 'alien_autoconf_with_pic' => 1 );
 
+# alien_inline_auto_include
+__PACKAGE__->add_property( 'alien_inline_auto_include' => [] );
+
+# use MSYS even if %c isn't found
+__PACKAGE__->add_property( 'alien_msys' => 0 );
+
+# Alien packages that provide build dependencies
+__PACKAGE__->add_property( 'alien_bin_requires' => {} );
+
 ################
 #  ConfigData  #
 ################
@@ -136,16 +151,25 @@ sub new {
   # setup additional temporary directories, and yes we have to add File::ShareDir manually
   $self->_add_prereq( 'requires', 'File::ShareDir', '1.00' );
 
+  # this just gets passed from the Build.PL to the config so that it can
+  # be used by the auto_include method
+  $self->config_data( 'inline_auto_include' => $self->alien_inline_auto_include );
+
   if (grep /(?<!\%)\%c/, @{ $self->alien_build_commands }) {
     $self->config_data( 'autoconf' => 1 );
   }
 
-  if ($^O eq 'MSWin32' && $self->config_data( 'autoconf')) {
+  if ($^O eq 'MSWin32' && ($self->config_data( 'autoconf') || $self->alien_msys)) {
     $self->_add_prereq( 'build_requires', 'Alien::MSYS', '0' );
     $self->config_data( 'msys' => 1 );
   } else {
     $self->config_data( 'msys' => 0 );
   }
+  
+  while(my($tool, $version) = each %{ $self->alien_bin_requires }) {
+    $self->_add_prereq( 'build_requires', $tool, $version );
+  }
+
 
   # force newest for all automated testing 
   #TODO (this probably should be checked for "input needed" rather than blindly assigned)
@@ -212,6 +236,28 @@ sub ACTION_code {
     # copy the compiled files into blib if running under blib scheme
     $self->depends_on('alien_install') if $self->notes('alien_blib_scheme');
   }
+  
+  my $module = $self->module_name;
+  my $file   = File::Spec->catfile($self->blib, 'lib', split /::/, "$module\::Install::Files.pm");
+  unless (-e $file) {
+    mkpath(File::Spec->catdir($self->blib, 'lib', split /::/, "$module\::Install"), { verbose => 0 });
+    open my $fh, '>', $file;
+    print $fh <<EOF;
+package $module\::Install::Files;
+require $module;
+sub Inline { shift; $module->Inline(\@_) }
+1;
+
+=begin Pod::Coverage
+
+  Inline
+
+=end Pod::Coverage
+
+=cut
+EOF
+    close $fh;
+  }
 }
 
 sub ACTION_alien_code {
@@ -282,6 +328,11 @@ sub ACTION_alien_code {
     $pc->{$self->alien_name} || $pc->{_manual}
   )->keyword('Version');
 
+  unless (defined $version) {
+    local $CWD = $self->config_data( 'working_directory' );
+    $version = $self->alien_check_built_version
+  }
+
   if (! $version and ! $pc_version) {
     carp "Library looks like it installed, but no version was determined";
     $self->config_data( version => 0 );    
@@ -455,7 +506,7 @@ sub alien_validate_repo {
 
   # if $valid is src, check for c compiler
   if ($platform eq 'src') {
-    return $self->have_c_compiler;
+    return !$repo->{c_compiler_required} || $self->have_c_compiler;
   }
 
   # $valid is a string (OS) to match against
@@ -505,18 +556,68 @@ sub alien_detect_blib_scheme {
 #  Build Methods  #
 ###################
 
-sub _msys_do_system {
+sub _env_do_system {
   my $self = shift;
   my $command = shift;
   
+  local $ENV{PATH} = $ENV{PATH};
+  
   if ($self->config_data( 'msys' )) {
-    require Alien::MSYS;
-    return Alien::MSYS::msys(sub { $self->do_system( $command ) });
+    $self->alien_bin_requires->{'Alien::MSYS'} ||= 0
+  }
+  
+  foreach my $mod (keys %{ $self->alien_bin_requires }) {
+    my $version = $self->alien_bin_requires->{$mod};
+    eval qq{ use $mod $version () }; # should also work for version = 0
+    die $@ if $@;
+    
+    my %path;
+    
+    if ($mod eq 'Alien::MSYS') {
+      $path{Alien::MSYS->msys_path} = 1;
+    } elsif ($mod eq 'Alien::CMake') {
+      Alien::CMake->set_path;
+    } elsif ($mod eq 'Alien::TinyCC') {
+      $path{Alien::TinyCC->path_to_tcc} = 1;
+    } elsif ($mod eq 'Alien::Autotools') {
+      $path{$_} = 1 for map { Alien::Autotools->$_ } qw( autoconf_dir automake_dir libtool_dir );
+    } elsif (eval { $mod->can('bin_dir') }) {
+      $path{$_} = 1 for $mod->bin_dir;
+    }
+    
+    # remove anything already in PATH
+    delete $path{$_} for @PATH;
+    # add anything else to start of PATH
+    unshift @PATH, sort keys %path;
+
+    my $config = Shell::Config::Generate->new;
+    $config->comment(
+      'this script sets the environment needed to build this package.',
+      'generated by: ' . __FILE__,
+    );
+    $config->prepend_path( PATH => sort keys %path );
+    if($^O eq 'MSWin32') {
+      local $CWD;
+      pop @CWD;
+      $config->generate_file( Shell::Guess->command_shell, 'env.bat' );
+      $config->generate_file( Shell::Guess->cmd_shell,     'env.cmd' );
+      $config->generate_file( Shell::Guess->power_shell,   'env.ps1' );
+    } else {
+      local $CWD;
+      pop @CWD;
+      $config->generate_file( Shell::Guess->bourne_shell,  'env.sh'  );
+      $config->generate_file( Shell::Guess->c_shell,       'env.csh' );
+    }
+
   }
   
   $self->do_system( $command );
 }
 
+sub alien_check_built_version {
+  return;
+}
+
 sub alien_do_commands {
   my $self = shift;
   my $phase = shift;
@@ -524,9 +625,11 @@ sub alien_do_commands {
   my $attr = "alien_${phase}_commands";
   my $commands = $self->$attr();
 
+  print "\n+ cd $CWD\n";
+
   foreach my $command (@$commands) {
 
-    my %result = $self->_msys_do_system( $command );
+    my %result = $self->_env_do_system( $command );
     unless ($result{success}) {
       carp "External command ($result{command}) failed! Error: $?\n";
       return 0;
@@ -550,6 +653,8 @@ sub do_system {
 
   my @args = map { $self->alien_interpolate($_) } @_;
 
+  print "+ @args\n";
+
   my ($out, $err, $success) = 
     $verbose
     ? tee     { $self->SUPER::do_system(@args) }
@@ -682,7 +787,7 @@ sub alien_generate_manual_pkgconfig {
 
   #if no provides_libs then generate -l list from found files
   unless ($provides_libs) {
-    my @files = map { "-l$_" } @{$paths->{so_files}};
+    my @files = map { "-l$_" } @{$paths->{lib_files}};
     $provides_libs = join( ' ', @files );
   } 
 
@@ -712,12 +817,18 @@ sub alien_generate_manual_pkgconfig {
   return $manual_pc;
 }
 
-sub _alien_file_pattern {
+sub _alien_file_pattern_dynamic {
   my $self = shift;
   my $ext = $self->config('so'); #platform specific .so extension
-  return qr/\.[\d.]*(?<=\.)$ext[\d.]*(?<!\.)|\.h$/;
+  return qr/\.[\d.]*(?<=\.)$ext[\d.]*(?<!\.)|(\.h|$ext)$/;
 };
 
+sub _alien_file_pattern_static {
+  my $self = shift;
+  my $ext = quotemeta $self->config('lib_ext');
+  return qr/(\.h|$ext)$/;
+}
+
 sub alien_find_lib_paths {
   my $self = shift;
   my ($dir) = @_;
@@ -726,43 +837,47 @@ sub alien_find_lib_paths {
   my @libs;
   @libs = grep { s/^-l// } split /\s+/, $libs if $libs;
 
-  my $file_pattern = $self->_alien_file_pattern;
+  my (@lib_files, @lib_paths, @inc_paths);
 
-  my @files =     
-    map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
-    grep { ! -d }
-    @{ $self->_rscan_destdir( $dir, $file_pattern ) };
+  foreach my $file_pattern ($self->_alien_file_pattern_static, $self->_alien_file_pattern_dynamic) {
 
-  my (@so_files, @lib_paths, @inc_paths);
-  for (@files) {
+    my @files =     
+      map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
+      grep { ! -d }
+      @{ $self->_rscan_destdir( $dir, $file_pattern ) };
 
-    my ($file, $path, $ext) = fileparse( $_, $file_pattern );
-    next unless $ext; # just in case
+    for (@files) {
 
-    $path = File::Spec->catdir($path); # remove trailing /
+      my ($file, $path, $ext) = fileparse( $_, $file_pattern );
+      next unless $ext; # just in case
 
-    if ($ext eq '.h') {
-      push @inc_paths, $path;
-      next;
+      $path = File::Spec->catdir($path); # remove trailing /
+
+      if ($ext eq '.h') {
+        push @inc_paths, $path;
+        next;
+      }
+
+      $file =~ s/^lib//;
+      
+      if (@libs) {
+        next unless grep { $file eq $_ } @libs;
+      }
+      
+      next if grep { $file eq $_ } @lib_files;
+
+      push @lib_files, $file;
+      push @lib_paths, $path;
     }
-
-    $file =~ s/^lib//;
-
-    if (@libs) {
-      next unless grep { $file eq $_ } @libs;
-    }
-
-    push @so_files, $file;
-    push @lib_paths, $path;
   }
 
-  @so_files = uniq @so_files;
-  @so_files = sort @so_files;
+  @lib_files = uniq @lib_files;
+  @lib_files = sort @lib_files;
 
   @lib_paths = uniq @lib_paths;
   @inc_paths = uniq @inc_paths;
 
-  return { lib => \@lib_paths, inc => \@inc_paths, so_files => \@so_files };
+  return { lib => \@lib_paths, inc => \@inc_paths, lib_files => \@lib_files };
 }
 
 sub alien_refresh_packlist {
@@ -884,6 +999,42 @@ build step of your distribution.  When properly configured it will
 
 =back
 
+=head1 METHODS
+
+=head2 alien_check_instaled_version
+
+ my $version = $abmb->alien_check_installed_version;
+
+This function determines if the library is already installed as part of
+the operating system, and returns the version as a string.  If it can't
+be detected then it should return empty list.
+
+The default implementation relies on C<pkg-config>, but you will probably
+want to override this with your own implementation if the package you are
+building does not use C<pkg-config>.
+
+=head2 alien_check_built_version
+
+ my $version = $amb->alien_check_built_version;
+
+This function determines the version of the library after it has been
+built from source.  This function only gets called if the operating
+system version can not be found and the package is successfully built.
+
+The default implementation relies on C<pkg-config>, and other huristics,
+but you will probably want to override this with your own implementation
+if the package you are building does not use C<pkg-config>.
+
+When this method is called, the current working directory will be the
+build root.
+
+If you see an error message like this:
+
+ Library looks like it installed, but no version was determined
+
+After the package is built from source code then you probably need to
+provide an implementation for this method.
+
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
