@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild::Repository;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -17,6 +17,9 @@ sub new {
 
   my $obj = bless \%self, $class;
 
+  $obj->{c_compiler_required} = 1
+    unless defined $obj->{c_compiler_required};
+
   return $obj;
 }
 
